@@ -6,6 +6,8 @@ use warnings;
 sub normalize_maketext_string {
     my ($filter) = @_;
 
+    return $filter->return_value_noop() if !$filter->run_extra_filters();
+
     my $string_sr = $filter->get_string_sr();
 
     if ( ${$string_sr} !~ m/\A(?:[A-Z]|(?:\[[^\]]+)|(?: …))/ ) {
@@ -46,3 +48,7 @@ Problem should be self explanatory.
 =head1 possible warnings
 
 None
+
+=head1 Entire filter only runs under extra filter mode.
+
+See L<Locale::Maketext::Utils::Phrase::Norm/extra filters> for more details.
